@@ -8,8 +8,6 @@ from datetime import datetime
 
 from tornado.options import options
 
-from lesscode.utils.encryption_algorithm import AES
-
 
 class EsHelper:
     """
@@ -101,9 +99,13 @@ class EsHelper:
             "扫描{}:{}条花费时间{}ms,".format(route_key, str(skip) + "-" + str(skip + data_size), res["took"]))
         scroll_id = res["_scroll_id"]
         result_list = []
+        try:
+            encryption_algorithm = importlib.import_module("lesscode_utils.encryption_algorithm")
+        except ImportError:
+            raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
         for data in res["hits"]["hits"]:
             if is_need_decrypt_oralce:
-                data["_id"] = AES.encrypt(options.aes_key, data["_id"])
+                data["_id"] = encryption_algorithm.AES.encrypt(key=options.aes_key, text=data["_id"])
             data["_source"]["_id"] = data["_id"]
             result_list.append(data["_source"])
         while True:
@@ -342,9 +344,13 @@ class EsHelper:
             "扫描{}:{}条花费时间{}ms,".format(route_key, str(skip) + "-" + str(skip + data_size), res["took"]))
         scroll_id = res["_scroll_id"]
         result_list = []
+        try:
+            encryption_algorithm = importlib.import_module("lesscode_utils.encryption_algorithm")
+        except ImportError:
+            raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
         for data in res["hits"]["hits"]:
             if is_need_decrypt_oralce:
-                data["_id"] = AES.encrypt(options.aes_key, data["_id"])
+                data["_id"] = encryption_algorithm.AES.encrypt(key=options.aes_key, text=data["_id"])
             data["_source"]["_id"] = data["_id"]
             result_list.append(data["_source"])
         while True:
@@ -363,7 +369,7 @@ class EsHelper:
                 break
             for data in res["hits"]["hits"]:
                 if is_need_decrypt_oralce:
-                    data["_id"] = AES.encrypt(options.aes_key, data["_id"])
+                    data["_id"] = encryption_algorithm.AES.encrypt(key=options.aes_key, text=data["_id"])
                 data["_source"]["_id"] = data["_id"]
                 result_list.append(data["_source"])
             if limit and limit <= len(result_list):
