@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
-import json
+import importlib
 import random
 
-import requests
-from requests.auth import HTTPBasicAuth
-
 
 class EsRequest:
 
     def __init__(self, host, port, user, password):
+
         # 主机地址
         self.host = host
         # 端口号
@@ -17,7 +15,11 @@ class EsRequest:
         self.user = user
         # 密码
         self.password = password
-        self.auth = HTTPBasicAuth(user, password)
+        try:
+            httpx = importlib.import_module("httpx")
+        except ImportError as e:
+            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+        self.auth = httpx.BasicAuth(user, password)
         host_str = host.split(",")
         self.hosts = [host for host in host_str]
 
@@ -49,9 +51,13 @@ class EsRequest:
         :param body:
         :return:
         """
-        r = requests.post(
+        try:
+            httpx = importlib.import_module("httpx")
+        except ImportError as e:
+            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+        r = httpx.post(
             url,
-            data=json.dumps(body),
+            json=body,
             headers={'content-type': "application/json"},
             params=params,
             auth=self.auth
@@ -67,10 +73,14 @@ class EsRequest:
         :param body:
         :return:
         """
-        r = requests.put(
+        try:
+            httpx = importlib.import_module("httpx")
+        except ImportError as e:
+            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+        r = httpx.put(
             url,
             params=params,
-            data=json.dumps(body),
+            json=body,
             headers={'content-type': "application/json"},
             auth=self.auth
         )
@@ -82,10 +92,13 @@ class EsRequest:
         发送http请求
         :param params:
         :param url:
-        :param body:
         :return:
         """
-        r = requests.get(
+        try:
+            httpx = importlib.import_module("httpx")
+        except ImportError as e:
+            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+        r = httpx.get(
             url,
             params=params,
             headers={'content-type': "application/json"},
@@ -94,17 +107,19 @@ class EsRequest:
         res = r.json()
         return res
 
-    def format_es_delete(self, url, body=None, params=None):
+    def format_es_delete(self, url, params=None):
         """
         发送http请求
         :param params:
         :param url:
-        :param body:
         :return:
         """
-        r = requests.delete(
+        try:
+            httpx = importlib.import_module("httpx")
+        except ImportError as e:
+            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+        r = httpx.delete(
             url,
-            data=json.dumps(body) if body else body,
             params=params,
             headers={'content-type': "application/json"},
             auth=self.auth
